@@ -1,5 +1,5 @@
 /*!
- * froala_editor v1.2.1 (http://editor.froala.com)
+ * froala_editor v1.2.3 (http://editor.froala.com)
  * Copyright 2014-2014 Froala
  */
 
@@ -15,8 +15,8 @@ $.Editable.LANGS['ja'] = {
     "Strikethrough": "\u53d6\u308a\u6d88\u3057\u7dda",
     "Font Size": "\u30d5\u30a9\u30f3\u30c8\u30b5\u30a4\u30ba",
     "Color": "\u30ab\u30e9\u30fc",
-    "Background Color": "\u80cc\u666f\u8272",
-    "Text Color": "\u6587\u5b57\u306e\u8272",
+    "Background": "\u80cc\u666f",
+    "Text": "\u30c6\u30ad\u30b9\u30c8",
     "Format Block": "\u66f8\u5f0f",
     "Normal": "\u30ce\u30fc\u30de\u30eb",
     "Paragraph": "\u6bb5\u843d",
@@ -51,7 +51,6 @@ $.Editable.LANGS['ja'] = {
     "Replace Image": "\u753b\u50cf\u3092\u4ea4\u63db\u3057\u3066\u304f\u3060\u3055\u3044",
     "Remove Image": "\u753b\u50cf\u3092\u524a\u9664",
     "Title": "\u30bf\u30a4\u30c8\u30eb",
-    "Insert image": "\u753b\u50cf\u306e\u633f\u5165",
     "Drop image": "\u753b\u50cf\u3092\u30c9\u30ed\u30c3\u30d7",
     "or click": "\u307e\u305f\u306f\u30af\u30ea\u30c3\u30af",
     "or": "\u307e\u305f\u306f",
