@@ -9,8 +9,9 @@ class FroalaEditor(widgets.Textarea):
     def __init__(self, *args, **kwargs):
         self.options = kwargs.pop('options', {})
         self.plugins = kwargs.pop('plugins', getattr(settings, 'FROALA_EDITOR_PLUGINS', (
-                                  'font_size', 'font_family', 'colors', 'block_styles', 'video', 'tables', 'media_manager', 'lists', 'file_upload'
-                                  )))
+            'font_size', 'font_family', 'colors', 'block_styles', 'video', 'tables', 'media_manager', 'lists',
+            'file_upload'
+        )))
         self.theme = kwargs.pop('theme', None)
         self.include_jquery = kwargs.pop('include_jquery', True)
         self.image_upload = kwargs.pop('image_upload', True)
@@ -33,11 +34,14 @@ class FroalaEditor(widgets.Textarea):
         options = dict(default_options.items()).copy()
         options.update(settings_options.items())
         options.update(self.options.items())
+        options.update([('imageUploadParams', {'csrfmiddlewaretoken': 'csrftokenplaceholder'})])
 
         if self.theme:
             options['theme'] = self.theme
 
-        return json.dumps(options)
+        json_options = json.dumps(options)
+        json_options = json_options.replace('"csrftokenplaceholder"', 'getCookie("csrftoken")')
+        return json_options
 
 
     def render(self, name, value, attrs=None):
@@ -47,6 +51,7 @@ class FroalaEditor(widgets.Textarea):
         return mark_safe(html)
 
     def trigger_froala(self, el_id, options):
+
         str = """
         <script>
             $(function(){
@@ -57,18 +62,19 @@ class FroalaEditor(widgets.Textarea):
 
     def _media(self):
         css = {
-        'all': ('froala_editor/css/font-awesome.min.css', 'froala_editor/css/froala_editor.min.css', 'froala_editor/css/froala_style.min.css', 'froala_editor/css/froala-django.css')
+            'all': ('froala_editor/css/font-awesome.min.css', 'froala_editor/css/froala_editor.min.css',
+                    'froala_editor/css/froala_style.min.css', 'froala_editor/css/froala-django.css')
         }
-        js = ('froala_editor/js/froala_editor.min.js',)
+        js = ('froala_editor/js/froala_editor.min.js','froala_editor/js/froala-django.js',)
 
         if self.include_jquery:
             js = ('froala_editor/js/libs/jquery-1.11.1.min.js',) + js
 
         if self.theme:
-            css['all'] += ('froala_editor/css/themes/'+self.theme+'.css',)
+            css['all'] += ('froala_editor/css/themes/' + self.theme + '.css',)
 
         for plugin in self.plugins:
-            js += ('froala_editor/js/plugins/'+plugin+'.min.js',)
+            js += ('froala_editor/js/plugins/' + plugin + '.min.js',)
 
         return Media(css=css, js=js)
 
